#
# spec file for package xmlto
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xmlto
VCS: https://src.suse.de/SLFO-pool/xmlto#28d7ea0d66f96d01581ef615cbe2275b4caf60e1c214b034924ed136a3dd02b8
Version:        0.0.28
Release:        160000.2.3
Summary:        Tool for Converting XML Files to Various Formats
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/XML
URL:            https://pagure.io/xmlto/
Source0:        https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2
Source10:       README.SUSE
Patch0:         xmlto-nonvoid.patch
Patch1:         xmlto-xsltopts.patch
Patch2:         xmlto-codecleanup.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libxslt-tools
BuildRequires:  sgml-skel
# We rely entirely on the DocBook XSL stylesheets!
Requires:       docbook-xsl-stylesheets >= 1.56.0
Requires:       docbook_4
Requires:       libxslt-tools
# For full functionality, we need passivetex; but since most users are not happy with
# getting texlive installed, we only suggest it.
Suggests:      texlive-xmltex >= 2007

%description
This is a package for converting XML files to various formats using XSL
stylesheets.  As a processor it depends on xsltproc and as a formatter
for print output it makes use of passivetex.

%prep
%autosetup -p1

cp %{SOURCE10} .
rm -f xmlif/xmlif.c

%build
%configure BASH=/bin/bash
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}%{_datadir}/xmlto/xsl
%fdupes %{buildroot}%{_datadir}/xmlto

%files
%doc README.SUSE
%license COPYING
%doc AUTHORS README ChangeLog FAQ THANKS NEWS
%{_bindir}/xmlto
%{_bindir}/xmlif
%{_mandir}/man1/xmlto.1%{?ext_man}
%{_mandir}/man1/xmlif.1%{?ext_man}
%{_datadir}/xmlto

%changelog
* Mon Feb 26 2024 dimstar@opensuse.org
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Mar 18 2019 dimstar@opensuse.org
- Suggest instead of recommend texlive: most users are not
  interested in texlive specific tooling- unless they install
  texlive. xmlto is also useful without the texlice stack. So
  instead of recommending (and this installing by default)
  textlive, we switch to suggesting it.
* Wed Mar  6 2019 mpluskal@suse.com
- Simplify spec file
* Tue Mar 13 2018 avindra@opensuse.org
- update to 0.0.28:
  - fix broken temp files removal
  - do not detect links browser as elinks
- includes 0.0.27:
  - remove several bashisms in scripts
  - new option --profile for preprocessing documents with
    profiling stylesheet
  - fix several potential crashes in xmlif
- cleanup with spec-cleaner
- switch urls to new fedora upstream
- patches:
  * rebase xmlto-xsltopts.patch
  * format xmlto-codecleanup.patch for -p1
  * format xmlto-nonvoid.patch for -p1
  * drop xmlto-overflow.patch (xmlif.c is regenerated anyway)
  * drop xmlto-lynx-empty-file.patch (obsolete)
  * renumber patches
* Sun Oct 19 2014 ledest@gmail.com
- fix shebang of xmlto
* Wed Jun 11 2014 tchvatal@suse.com
- Version bump to 0.0.26:
  - --searchpath option no longer produces warning
    about local builtin used outside the function
    (debian #652974)
  - fix build with automake 1.13+
  - fix noextensions option recognition
  - handle used css list in epub format
- Rename SUSE readme to xmlto-README.SUSE to fix capitalization
- Rebase xmlto-xsltopts.patch to apply to latest release.
* Thu Dec  6 2012 pascal.bleser@opensuse.org
- fixed xsltproc buildrequires and requires for other versions
- more consistent spec file
* Wed Dec  5 2012 pascal.bleser@opensuse.org
- add explicit requires for libxslt-tools or libxslt1 in order to
  fix "have choice" in several repos
* Wed Apr 18 2012 chris@computersalat.de
- update to 0.0.25
  - 2011-11-28  Ondrej Vasik <ovasik@redhat.com>
  * configure.in: detect grep location
  * xmlto.in: use (fop/fop1).extensions parameter based on real
    fop version
  - 2011-07-14  Ondrej Vasik <ovasik@redhat.com>
  * format/docbook/epub: initial experimental support for
    docbook to epub conversion
  * configure.in: detect zip location
  * xmlto.in: provide detected zip location to epub convertor
  - 2011-07-07  Ondrej Vasik <ovasik@redhat.com>
  * README: Improve the readme file, create online manual
    pages on project wiki
  * xmlto.in: use backend extensions by default, provide
  - -noextensions to disable this
  * doc/xmlto.xml: mention --noextensions option in documentation
  - 2011-03-03  Ondrej Vasik <ovasik@redhat.com>
  * format/{docbook,xhtml}/txt: show the text-web-browser
    converting command in verbose mode
  - 2010-07-13  Ondrej Vasik <ovasik@redhat.com>
  * format/fo/{ps,dvi,pdf}: workaround passivetex limitation
    for chapters titles starting with L (rhbz#526273)
- rebase patches (xmlto-overflow.patch, xmlto-xsltopts.patch).
* Wed Oct 19 2011 idonmez@suse.com
- Add xmlto-lynx-empty-file.patch to fix problems with lynx on
  empty files, upstream commit 57
* Wed Jun  8 2011 ke@suse.de
- Install missing %%doc files such as COPYING; bnc#695072.
* Wed May 18 2011 giecrilj@stegny.2a.pl
- Recommends texlive (bnc#688032)
* Sat Dec 19 2009 jengelh@medozas.de
- Enable parallel build
* Wed Dec 16 2009 ke@suse.de
- Update to version 0.0.23; reported by Andreas Schwab.
- Drop obsolete patch.
- Rebuild old patches.
* Tue Apr 28 2009 pth@suse.de
- Fix comiler warnings.
- BuildRequire flex and remove xmlif.c to get it regenerated.
* Tue Sep  9 2008 ke@suse.de
- Improve README.SUSE; bnc#67190.
* Mon Mar 17 2008 werner@suse.de
- Use texlive-xmltex instead of passivetex
* Fri Dec 14 2007 ke@suse.de
- Require libxslt again.
* Wed Dec 12 2007 ke@suse.de
- Cleanup spec file.
- Apply xmlto-0.0.18-xsltopts.diff to provide a command line switch for
  specifying the HTML output encoding; see # 197484 (thanks to Thomas
  Schraitle).
* Mon Aug 28 2006 ke@suse.de
- Fix find argument sequence; reported by Marcus Rueckert [#201749].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Wed Jul  6 2005 ke@suse.de
- xmlto-0.0.18-overflow.patch: Include more *.h to avoid potential
  buffer overflows.
* Thu Mar  3 2005 ke@suse.de
- Add README.SuSE to address issues producing PDF output; [# 67190].
* Wed Oct 13 2004 ke@suse.de
- Add libgpg-error and libgcrypt to neededforbuild.
* Wed May 19 2004 ro@suse.de
- added return to non-void function (main)
* Tue Feb 24 2004 ke@suse.de
- New package: version 0.0.18.  Proposed by Richard Bos [# 34918].
